#=========================================================================#
#           Trichoptera Abundance and Diversity in the Ogeechee River     #
#=========================================================================#
## Authors: Kelly Murray-Stoker & David Murray-Stoker
## Updated: 13 October 2019

library(plyr) # Load before dplyr to avoid any potential issues

library(agricolae)
library(dplyr)
library(FD)
library(ggplot2)
library(grid)
library(gridExtra)
library(gtable)
library(reshape2)
library(vegan)


## Set working directory
#setwd("~/Documents/OGC-CD/Trichoptera_ch") # KMS computer
setwd("~/Documents/Research/OGC-trichoptera/CSV Files") # DMS computer

## Source code for helper functions and themes for creating figures
source("~/Documents/R Materials/R Script/DMS-ggplot2-supplement.R") # DMS computer


## Trichoptera genera/family/order density data
full.trichop <- read.csv("Trichop-density_data.csv")
tri.info <- full.trichop[, 1:4]

## Apply ln-transformation to trichoptera densities
taxa.data <- full.trichop[, 5:26]
ln.taxa <- log(taxa.data + 1)
ln.data <- data.frame(tri.info, ln.taxa)

## ANOVA of total densities by period and season---------------------------

## Visualize density data by period and season
par(mfrow = c(1, 1))
boxplot(Density ~ Period * Season, data = ln.data)
# Some evidence of unequal variance, even on transformed data. Further transformations
# offered no improvement, so staying with the ln-transformation.

## Run an ANOVA on densities by period and season
aov.total <- aov(Density ~ Period * Season, data = ln.data)
summary(aov.total)

## Tukey groups (season)
total.season.HSD.groups <- HSD.test(aov.total, trt = c("Season"), group = TRUE)
total.season.HSD.groups

## Check model assumptions
par(mfrow = c(2, 2))
plot(aov.total)
# Model assumptions seem to be met, but fitted values vs. standardized residuals 
# could be better: downward trend as fitted values increase. All other diagnostics
# are met.

## Get summaries of densities by season
spring <- ln.data[which(ln.data$Season == "spring"), ]
mean(spring$Density)
(sd(spring$Density))/sqrt(12)

summer <- ln.data[which(ln.data$Season == "summer"), ]
mean(summer$Density)
(sd(summer$Density))/sqrt(14)

fall <- ln.data[which(ln.data$Season == "fall"), ]
mean(fall$Density)
(sd(fall$Density))/sqrt(12)

winter <- ln.data[which(ln.data$Season == "winter"), ]
mean(winter$Density)
(sd(winter$Density))/sqrt(11)

## Plot density against season
par(mfrow = c(1, 1))
boxplot(Density ~ Season, data = ln.data)

## Community analyses------------------------------------------------------

## Setup community matrix
ln.com.data <- subset(ln.taxa, select = -c(Density))
ln.com.df <- data.frame(tri.info, ln.com.data)

## Apply Bray-Curtis dissimilarity index to community matrix
BC.dist.tri <- vegdist(ln.com.data, method = "bray")
BC.NMDS.tri <- monoMDS(BC.dist.tri, k = 2, model = "global")
BC.NMDS.tri

## PERMANOVA with 10000 permutations
adonis(BC.dist.tri ~ Period * Season, data = ln.com.df, permutations = 10000)

## Set dataframe of NMDS scores
score.nmds.tri <- scores(BC.NMDS.tri)

## Taxon specific change---------------------------------------------------

## Subset data to only contain taxa identified to genus
genus.data <- subset(taxa.data, select = -c(Hydropsychidae, Hydroptilidae,
                                            Leptoceridae, Trichoptera,
                                            Polycentropodidae, Density))
## Further subset data by period
gen.data.80 <- genus.data[1:25, ]
gen.data.10 <- genus.data[26:49, ]

## Get summaries and mean values for each time period
sum.80 <- as.data.frame(colSums(gen.data.80))
avg.80 <- (sum.80$`colSums(gen.data.80)`)/25

sum.10 <- as.data.frame(colSums(gen.data.10))
avg.10 <- (sum.10$`colSums(gen.data.10)`)/24

diff <- avg.10 - avg.80
per.change <- ((diff)/(avg.10))*100

## Set final dataframe for genus-level total and mean abundances
final.gen <- data.frame(sum.80, sum.10, avg.80, avg.10, diff, per.change)

## Bootstrapped CI for % abundance change----------------------------------

## Taxa list
taxa.list <- data.frame(rownames(final.gen))
names(taxa.list) <- "taxon"

## Dataframe for all percent change results
pct.change.data <- data.frame("taxon" = character(length = 16),
                              "mean.pct.change" = numeric(length = 16),
                              "LL_95CI" = numeric(length = 16),
                              "UL_95CI" = numeric(length = 16))

## Allow for reproducible results
set.seed(666)

for(x in 1:16){
  
  ## Bootstrapping the differences----------------------------------------#
  
  ## Data for boostrapped biomass differences
  pct.change.bootstrapped <- NULL
  
  ## Bootstrap distribution of taxa
  for(y in 1:5000){
    T1.taxon.bootstrapped <- sample(gen.data.80[, x], size = 25, replace = TRUE)
    T2.taxon.bootstrapped <- sample(gen.data.10[, x], size = 24, replace = TRUE)
    pct.change.bootstrapped[y] <- (((mean(T2.taxon.bootstrapped + 1) - 
                mean(T1.taxon.bootstrapped + 1))/mean(T2.taxon.bootstrapped 
                                              + 1))*100)
  }
  
  ## 95% confidence interval (CI)
  pct.change.CI <- as.data.frame(quantile(pct.change.bootstrapped, c(0.025, 0.975),
                                          na.rm = TRUE))
  
  pct.change.data[x, 2] <- mean(pct.change.bootstrapped, na.rm = TRUE)
  pct.change.data[x, 3] <- pct.change.CI[1, ]
  pct.change.data[x, 4] <- pct.change.CI[2, ]
}

## Add taxon names to dataframe
pct.change.data$taxon <- taxa.list

## Sensitivity analyses----------------------------------------------------

## Define community matrix for sensitivity analyses
sens.mat <- ln.taxa

## Subset sensitivity matrix to only include taxa identified to genus
sens.mat <- subset(sens.mat, select = -c(Hydropsychidae, Hydroptilidae,
                                         Leptoceridae, Trichoptera,
                                         Polycentropodidae, Density))

## Add vector of densities to sensitivity matrix
sens.mat$Density <- rowSums(sens.mat)

## Multiply taxa by their specific sensitivity values
sens.mat[, 1] <- (sens.mat[, 1] * 4.4)    # Neureclipsis
sens.mat[, 2] <- (sens.mat[, 2] * 7.4)    # Cyrnellus
sens.mat[, 3] <- (sens.mat[, 3] * 4.0)    # Cernotina
sens.mat[, 4] <- (sens.mat[, 4] * 2.8)    # Chimarra
sens.mat[, 5] <- (sens.mat[, 5] * 5.0)    # Hydropsyche
sens.mat[, 6] <- (sens.mat[, 6] * 6.6)    # Cheumatopsyche
sens.mat[, 7] <- (sens.mat[, 7] * 3.6)    # Macrostemum
sens.mat[, 8] <- (sens.mat[, 8] * 6.2)    # Hydroptila
sens.mat[, 9] <- (sens.mat[, 9] * 2.0)    # Neotrichia
sens.mat[, 10] <- (sens.mat[, 10] * 6.4)  # Ceraclea
sens.mat[, 11] <- (sens.mat[, 11] * 5.7)  # Oecetis
sens.mat[, 12] <- (sens.mat[, 12] * 4.2)  # Nectopsyche
sens.mat[, 13] <- (sens.mat[, 13] * 4.3)  # Triaenodes
sens.mat[, 14] <- (sens.mat[, 14] * 1.8)  # Brachycentus
sens.mat[, 15] <- (sens.mat[, 15] * 7.3)  # Ironoquia
sens.mat[, 16] <- (sens.mat[, 16] * 2.3)  # Pycnopsyche

## Add vector of total and mean sensitivity values to sensitivity matrix
sens.mat$SumSens <- rowSums(sens.mat[1:16])
sens.mat$AvgSens <- (sens.mat$SumSens)/(sens.mat$Density)

## Add sampling data to the dataframe
sens.mat$Period <- tri.info$Period
sens.mat$Season <- tri.info$Season

## Subset the dataframe by sampling period
sens.80 <- sens.mat[1:25, ]
sens.10 <- sens.mat[26:49, ]

## Visualize sensitivity data by period and season
par(mfrow = c(1, 1))
boxplot(AvgSens ~ Period * Season, data = sens.mat)
# Some evidence of unequal variance

## Run an ANOVA on mean sensitivity values by period and season
aov.sens <- aov(AvgSens ~ Period * Season, data = sens.mat)
summary(aov.sens)

## Tukey groups (season, period, interaction)
sens.season.HSD.groups <- HSD.test(aov.sens, trt = c("Season"), group = TRUE)
sens.season.HSD.groups

sens.period.HSD.groups <- HSD.test(aov.sens, trt = c("Period"), group = TRUE)
sens.period.HSD.groups

sens.interaction.HSD.groups <- HSD.test(aov.sens, trt = c("Season", "Period"), group = TRUE)
sens.interaction.HSD.groups

## Check model assumptions
par(mfrow = c(2, 2))
plot(aov.sens)
# Model assumptions seem to be met, but fitted values vs. standardized residuals 
# could be better: downward trend as fitted values increase. All other diagnostics
# are met.

## Get summaries of sensitivity values by period
mean(sens.80$AvgSens)
(sd(sens.80$AvgSens))/sqrt(25)
mean(sens.10$AvgSens)
(sd(sens.10$AvgSens))/sqrt(24)

## Get summaries of sensitivity values by season and period
spring.sens.80 <- sens.80[which(sens.80$Season == "spring"), ]
mean(spring.sens.80$AvgSens)
(sd(spring.sens.80$AvgSens))/sqrt(6)

summer.sens.80 <- sens.80[which(sens.80$Season == "summer"), ]
mean(summer.sens.80$AvgSens)
(sd(summer.sens.80$AvgSens))/sqrt(7)

fall.sens.80 <- sens.80[which(sens.80$Season == "fall"), ]
mean(fall.sens.80$AvgSens)
(sd(fall.sens.80$AvgSens))/sqrt(6)

winter.sens.80 <- sens.80[which(sens.80$Season == "winter"), ]
mean(winter.sens.80$AvgSens)
(sd(winter.sens.80$AvgSens))/sqrt(6)

spring.sens.10 <- sens.10[which(sens.10$Season == "spring"), ]
mean(spring.sens.10$AvgSens)
(sd(spring.sens.10$AvgSens))/sqrt(6)

summer.sens.10 <- sens.10[which(sens.10$Season == "summer"), ]
mean(summer.sens.10$AvgSens)
(sd(summer.sens.10$AvgSens))/sqrt(7)

fall.sens.10 <- sens.10[ which(sens.10$Season == "fall"), ]
mean(fall.sens.10$AvgSens)
(sd(fall.sens.10$AvgSens))/sqrt(6)

winter.sens.10 <- sens.10[ which(sens.10$Season == "winter"), ]
mean(winter.sens.10$AvgSens)
(sd(winter.sens.10$AvgSens))/sqrt(5)

## Comparison with ASPT
ASPT.sens <- read.csv("Trichop-ASPT_data.csv")

## Run an ANOVA on ASPT by period and season
aov.ASPT <- aov(ASPT ~ Period * Season, data = ASPT.sens)
summary(aov.ASPT)

## Tukey groups (season, period, interaction)
ASPT.season.HSD.groups <- HSD.test(aov.ASPT, trt = c("Season"), group = TRUE)
ASPT.season.HSD.groups

ASPT.period.HSD.groups <- HSD.test(aov.ASPT, trt = c("Period"), group = TRUE)
ASPT.period.HSD.groups

ASPT.interaction.HSD.groups <- HSD.test(aov.ASPT, trt = c("Season", "Period"), group = TRUE)
ASPT.interaction.HSD.groups

## Plot ASPT by period and season
par(mfrow = c(1, 1))
boxplot(ASPT ~ Period * Season, data = ASPT.sens)

## Subset ASPT data by period
ASPT.80 <- ASPT.sens[1:25, ]
ASPT.10 <- ASPT.sens[26:49,]

## Subset data and get summaries of ASPT
mean(ASPT.80$ASPT)
(sd(ASPT.80$ASPT))/sqrt(25)
winter.ASPT.80 <- ASPT.80[which(ASPT.80$Season == "winter"), ]
spring.ASPT.80 <- ASPT.80[which(ASPT.80$Season == "spring"), ]
summer.ASPT.80 <- ASPT.80[which(ASPT.80$Season == "summer"), ]
fall.ASPT.80   <- ASPT.80[which(ASPT.80$Season == "fall"), ]

mean(winter.ASPT.80$ASPT)
(sd(winter.ASPT.80$ASPT))/sqrt(6)

mean(spring.ASPT.80$ASPT)
(sd(spring.ASPT.80$ASPT))/sqrt(6)

mean(summer.ASPT.80$ASPT)
(sd(summer.ASPT.80$ASPT))/sqrt(7)

mean(fall.ASPT.80$ASPT)
(sd(fall.ASPT.80$ASPT))/sqrt(6)

mean(ASPT.10$ASPT)
(sd(ASPT.10$ASPT))/sqrt(24)
winter.ASPT.10 <- ASPT.10[which(ASPT.10$Season == "winter"), ]
spring.ASPT.10 <- ASPT.10[which(ASPT.10$Season == "spring"), ]
summer.ASPT.10 <- ASPT.10[which(ASPT.10$Season == "summer"), ]
fall.ASPT.10   <- ASPT.10[which(ASPT.10$Season == "fall"), ]

mean(winter.ASPT.10$ASPT)
(sd(winter.ASPT.10$ASPT))/sqrt(5)

mean(spring.ASPT.10$ASPT)
(sd(spring.ASPT.10$ASPT))/sqrt(6)

mean(summer.ASPT.10$ASPT)
(sd(summer.ASPT.10$ASPT))/sqrt(7)

mean(fall.ASPT.10$ASPT)
(sd(fall.ASPT.10$ASPT))/sqrt(6)

## FFG percent composition-------------------------------------------------

## Read in and format FFG data
FFG.data <- read.csv("TrichopFFG.csv")
gen.mean.den80s <- colMeans(genus.data[1:25, ])
FFG.data$MeanDen80 <- gen.mean.den80s
gen.mean.den10s <- colMeans(genus.data[26:49, ])
FFG.data$MeanDen10 <- gen.mean.den10s

## Subset data by FFG
CF.data <- subset(FFG.data, FFG == "CF")
CG.data <- subset(FFG.data, FFG == "CG")
HB.data <- subset(FFG.data, FFG == "HB")
PR.data <- subset(FFG.data, FFG == "PR")
SC.data <- subset(FFG.data, FFG == "SC")
SH.data <- subset(FFG.data, FFG == "SH")

## Get total densities for each period
total.80 <- sum(FFG.data$MeanDen80)
total.10 <- sum(FFG.data$MeanDen10)

## Calculate percent composition of each FFG for each period
CF.80 <- (sum(CF.data$MeanDen80)/total.80)*100
CG.80 <- (sum(CG.data$MeanDen80)/total.80)*100
HB.80 <- (sum(HB.data$MeanDen80)/total.80)*100
PR.80 <- (sum(PR.data$MeanDen80)/total.80)*100
SC.80 <- (sum(SC.data$MeanDen80)/total.80)*100
SH.80 <- (sum(SH.data$MeanDen80)/total.80)*100

CF.10 <- (sum(CF.data$MeanDen10)/total.10)*100
CG.10 <- (sum(CG.data$MeanDen10)/total.10)*100
HB.10 <- (sum(HB.data$MeanDen10)/total.10)*100
PR.10 <- (sum(PR.data$MeanDen10)/total.10)*100
SC.10 <- (sum(SC.data$MeanDen10)/total.10)*100
SH.10 <- (sum(SH.data$MeanDen10)/total.10)*100

## Format FFG dataframe for chi-square test
df.FFG <- as.data.frame(data.frame(matrix(0, nrow = 6, ncol = 2)))
colnames(df.FFG) <- c("1980s", "2010s")
rownames(df.FFG) <- c("CF", "CG", "HB", "PR", "SC", "SH")
df.FFG$`1980s` <- c(CF.80, CG.80, HB.80, PR.80, SC.80, SH.80)
df.FFG$`2010s` <- c(CF.10, CG.10, HB.10, PR.10, SC.10, SH.10)

## Run chi-square test on FFG percent compositions
chi.FFG <- chisq.test(df.FFG)
chi.FFG
chi.FFG$residuals

df.mat <- as.matrix(df.FFG)

## Adding error to % FFG plot
genusSum <- rowSums(genus.data)

## Subset matrix by taxa in each FFG
CF.mat <- subset(genus.data, select = c(Neureclipsis, Cyrnellus, Chimarra,
                                        Hydropsyche, Cheumatopsyche, Macrostemum, 
                                        Brachycentrus))
CG.mat <- subset(genus.data, select = c(Ceraclea))
HB.mat <- subset(genus.data, select = c(Hydroptila))
PR.mat <- subset(genus.data, select = c(Oecetis, Cernotina))
SC.mat <- subset(genus.data, select = c(Neotrichia))
SH.mat <- subset(genus.data, select = c(Nectopsyche, Triaenodes, Ironoquia, 
                                        Pycnopsyche))

## Get sums for each FFG
sum.CG <- rowSums(CG.mat)
sum.CF <- rowSums(CF.mat)
sum.HB <- rowSums(HB.mat)
sum.PR <- rowSums(PR.mat)
sum.SC <- rowSums(SC.mat)
sum.SH <- rowSums(SH.mat)

## Calculate the percentage for each FFG
pct.CG <- as.data.frame(((sum.CG)/(genusSum))*100)
pct.CF <- as.data.frame(((sum.CF)/(genusSum))*100) 
pct.HB <- as.data.frame(((sum.HB)/(genusSum))*100)
pct.PR <- as.data.frame(((sum.PR)/(genusSum))*100)
pct.SC <- as.data.frame(((sum.SC)/(genusSum))*100)
pct.SH <- as.data.frame(((sum.SH)/(genusSum))*100)

## Create a percent FFG dataframe
pct.FFG        <- bind_cols(pct.CG, pct.CF, pct.HB, pct.PR, pct.SC, pct.SH)
names(pct.FFG) <- c("CG", "CF", "HB", "PR", "SC", "SH")

## Get summaries for eaach FFG
FFG.df <- data.frame(tri.info, pct.FFG)
FFG.80 <- FFG.df[1:25, ]
FFG.10 <- FFG.df[26:49, ]

# LL 95% CI 1980s
CG.80.LL  <- quantile(na.omit(FFG.80$CG), 0.025)
CF.80.LL  <- quantile(na.omit(FFG.80$CF), 0.025)
HB.80.LL  <- quantile(na.omit(FFG.80$HB), 0.025)
PR.80.LL  <- quantile(na.omit(FFG.80$PR), 0.025)
SC.80.LL  <- quantile(na.omit(FFG.80$SC), 0.025)
SH.80.LL  <- quantile(na.omit(FFG.80$SH), 0.025)

# UL 95% CI 1980s
CG.80.UL  <- quantile(na.omit(FFG.80$CG), 0.975)
CF.80.UL  <- quantile(na.omit(FFG.80$CF), 0.975)
HB.80.UL  <- quantile(na.omit(FFG.80$HB), 0.975)
PR.80.UL  <- quantile(na.omit(FFG.80$PR), 0.975)
SC.80.UL  <- quantile(na.omit(FFG.80$SC), 0.975)
SH.80.UL  <- quantile(na.omit(FFG.80$SH), 0.975)


# LL 95% CI 2010s
CG.10.LL  <- quantile(na.omit(FFG.10$CG), 0.025)
CF.10.LL  <- quantile(na.omit(FFG.10$CF), 0.025)
HB.10.LL  <- quantile(na.omit(FFG.10$HB), 0.025)
PR.10.LL  <- quantile(na.omit(FFG.10$PR), 0.025)
SC.10.LL  <- quantile(na.omit(FFG.10$SC), 0.025)
SH.10.LL  <- quantile(na.omit(FFG.10$SH), 0.025)

# UL 95% CI 2010s
CG.10.UL  <- quantile(na.omit(FFG.10$CG), 0.975)
CF.10.UL  <- quantile(na.omit(FFG.10$CF), 0.975)
HB.10.UL  <- quantile(na.omit(FFG.10$HB), 0.975)
PR.10.UL  <- quantile(na.omit(FFG.10$PR), 0.975)
SC.10.UL  <- quantile(na.omit(FFG.10$SC), 0.975)
SH.10.UL  <- quantile(na.omit(FFG.10$SH), 0.975)

## Format dataframe of 95% CIs
FFG.95.CI <- as.data.frame(data.frame(matrix(0, nrow = 6, ncol = 4)))
colnames(FFG.95.CI) <- c("1980s.LL", "1980s.UL", "2010s.LL", "2010s.UL")
rownames(FFG.95.CI) <- c("CF", "CG", "HB", "PR", "SC", "SH")
FFG.95.CI$`1980s.LL` <- c(CF.80.LL, CG.80.LL, HB.80.LL, PR.80.LL, SC.80.LL, SH.80.LL)
FFG.95.CI$`1980s.UL` <- c(CF.80.UL, CG.80.UL, HB.80.UL, PR.80.UL, SC.80.UL, SH.80.UL)
FFG.95.CI$`2010s.LL` <- c(CF.10.LL, CG.10.LL, HB.10.LL, PR.10.LL, SC.10.LL, SH.10.LL)
FFG.95.CI$`2010s.UL` <- c(CF.10.UL, CG.10.UL, HB.10.UL, PR.10.UL, SC.10.UL, SH.10.UL)

FFG.95.CI.mat <- as.matrix(FFG.95.CI)
FFG.95.CI.plot <- t(FFG.95.CI.mat)


## Functional diversity of all Trichoptera---------------------------------
trichop.traits <- read.csv("Trichop-trait_table.csv", row.names = "Taxon")

## Quantify the gower distance on the functional trait matrix
trich.dist <- gowdis(trichop.traits, ord = "podani")
hc.trichop <- hclust(trich.dist)

## Data formatting
ln.genus.f   <- ln.taxa[, 1:17]
ln.genus     <- subset(ln.genus.f, select = -c(Hydropsychidae))


## Calculate functional trait diversity metrics
FD.data.all <- as.data.frame(dbFD(trichop.traits, ln.genus, m = "min",
                                  stand.FRic = TRUE, calc.CWM = FALSE,
                                  corr = "none", messages = FALSE))

## Format final functional diversity dataframe
FD.data.final <- cbind.data.frame(tri.info, FD.data.all)

## Visualize FRic data by period and season
par(mfrow = c(1, 1))
boxplot(FRic ~ Period * Season, data = FD.data.final)
# Evidence of unequal variance, but model assumption not greatly improved with
# standard transformations

## ANOVA of FRic by period and season
aov.FRic <- aov(FRic ~ Period * Season, data = FD.data.final, na.action = na.omit)
summary(aov.FRic)

## Tukey groups (period)
FRic.period.HSD.groups <- HSD.test(aov.FRic, trt = c("Period"), group = TRUE)
FRic.period.HSD.groups

## Check model assumptions
par(mfrow = c(2, 2))
plot(aov.FRic)


## Visualize FEve data by period and season
par(mfrow = c(1, 1))
boxplot(FEve ~ Period * Season, data = FD.data.final)
# Evidence of unequal variance, but model assumption not greatly improved with
# standard transformations

## ANOVA of FEve by period and season
aov.FEve <- aov(FEve ~ Period * Season, data = FD.data.final, na.action = na.omit)
summary(aov.FEve)

## Tukey groups (period)
FEve.period.HSD.groups <- HSD.test(aov.FEve, trt = c("Period"), group = TRUE)
FEve.period.HSD.groups

## Check model assumptions
par(mfrow = c(2, 2))
plot(aov.FEve)


## Visualize FDiv data by period and season
par(mfrow = c(1, 1))
boxplot(FDiv ~ Period * Season, data = FD.data.final)
# Evidence of unequal variance, but model assumption not greatly improved with
# standard transformations

## ANOVA of FDiv by period and season
aov.FDiv <- aov(FDiv ~ Period * Season, data = FD.data.final, na.action = na.omit)
summary(aov.FDiv)

## No tukey groups quantified as there were no main effects or interaction

## Check model assumptions
par(mfrow = c(2, 2))
plot(aov.FDiv)

## Visualize FDis data by period and season
par(mfrow = c(1, 1))
boxplot(FDis ~ Period * Season, data = FD.data.final)
# Some evidence of unequal variance, but model assumption not greatly improved with
# standard transformations

## ANOVA of FDis by period and season
aov.FDis <- aov(FDis ~ Period * Season, data = FD.data.final, na.action = na.omit)
summary(aov.FDis)

## Tukey groups (season, period, interaction)
FDis.season.HSD.groups <- HSD.test(aov.FDis, trt = c("Season"), group = TRUE)
FDis.season.HSD.groups

FDis.period.HSD.groups <- HSD.test(aov.FDis, trt = c("Period"), group = TRUE)
FDis.period.HSD.groups

FDis.interaction.HSD.groups <- HSD.test(aov.FDis, trt = c("Season", "Period"), group = TRUE)
FDis.interaction.HSD.groups

## Check model assumptions
par(mfrow = c(2, 2))
plot(aov.FDis)
par(mfrow = c(1, 1))


## Summary of FRic by period and season
FRic.summary <- ddply(FD.data.final, c("Period", "Season"), summarise,
                      N    = sum(!is.na(FRic)),
                      mean = mean(FRic, na.rm = TRUE),
                      sd   = sd(FRic, na.rm = TRUE),
                      se   = sd / sqrt(N),
                      LL   = quantile(na.omit(FRic), 0.025),
                      UL   = quantile(na.omit(FRic), 0.975)
)

## Summary of FEve by period and season
FEve.summary <- ddply(FD.data.final, c("Period", "Season"), summarise,
                      N    = sum(!is.na(FEve)),
                      mean = mean(FEve, na.rm = TRUE),
                      sd   = sd(FEve, na.rm = TRUE),
                      se   = sd / sqrt(N),
                      LL   = quantile(na.omit(FEve), 0.025),
                      UL   = quantile(na.omit(FEve), 0.975)
)

## Summary of FDiv by period and season
FDiv.summary <- ddply(FD.data.final, c("Period", "Season"), summarise,
                      N    = sum(!is.na(FDiv)),
                      mean = mean(FDiv, na.rm = TRUE),
                      sd   = sd(FDiv, na.rm = TRUE),
                      se   = sd / sqrt(N),
                      LL   = quantile(na.omit(FDiv), 0.025),
                      UL   = quantile(na.omit(FDiv), 0.975)
)

## Summary of FDis by period and season
FDis.summary <- ddply(FD.data.final, c("Period", "Season"), summarise,
                      N    = sum(!is.na(FDis)),
                      mean = mean(FDis, na.rm = TRUE),
                      sd   = sd(FDis, na.rm = TRUE),
                      se   = sd / sqrt(N),
                      LL   = quantile(na.omit(FDis), 0.025),
                      UL   = quantile(na.omit(FDis), 0.975)
)


## Figures-----------------------------------------------------------------

# NMDS
plot(score.nmds.tri, xlab = "NMDS Axis 1", ylab = "NMDS Axis 2", 
     ylim = c(-2.0, 3.0), xlim = c(-1.5, 2.5), las = 1,
     bg=c(rep("cadetblue", times = 3), rep("olivedrab3", times = 3), 
          rep("gold", times = 3), rep("tomato", times = 3), 
          rep("cadetblue", times = 3), rep("olivedrab3", times = 3), 
          rep("gold", times = 4), rep("tomato", times = 3), 
          rep("gold", times = 2), rep("tomato", times = 3), 
          rep("cadetblue", times=2), rep("olivedrab3", times = 3), 
          rep("gold", times = 2), rep("tomato", times = 3), 
          rep("cadetblue", times = 3), rep("olivedrab3", times = 3), 
          rep("gold", times = 3)), pch = c(rep(21, times = 25), 
          rep(24, times = 24)), col = "black", cex = 1.5, lwd = 0.5)
mtext(text = "Stress = 0.18", side = 3, line = -1.5, adj = 0.95, cex = 0.8)
legend(1.7, 2.5, c("1980s", "2010s"), col = "black", pch = c(21, 24), cex = 0.8)
mtext(text = "Winter", side = 1, line = -1.5, adj = 0.53, cex = 1.5, col = "cadetblue")
mtext(text = "Spring", side = 1, line = -1.5, adj = 0.65, cex = 1.5, col = "olivedrab3")
mtext(text = "Summer", side = 1, line = -1.5, adj = 0.8, cex = 1.5, col = "gold")
mtext(text = "Fall", side = 1, line = -1.5, adj = 0.9, cex = 1.5, col = "tomato")
with(ln.com.df, ordiellipse(BC.NMDS.tri, Period, draw = "lines", 
                            col = "gray", show.groups = "1980s",lwd = 2))
with(ln.com.df, ordiellipse(BC.NMDS.tri, Period, draw = "lines", 
                            col = "black", show.groups = "2010s",lwd = 2))


# Bootstrapped % change
par(mar = c(5, 6, 2, 5))
taxa.plot <- barplot(pct.change.data$mean.pct.change, horiz = TRUE, 
              names.arg = row.names(final.gen),
              las = 1, cex.names = 0.7, col = c(rep("firebrick1", times = 3), 
              rep("orange", times = 1), rep("gold1", times = 3),
              rep("yellowgreen", times = 2), rep("forestgreen", times = 4), 
              rep("lightseagreen", times = 1), rep("dodgerblue3", 
              times = 2)), xlab = "% abundance difference", xlim = c(-1000, 200))
arrows(pct.change.data$UL_95CI, taxa.plot, pct.change.data$LL_95CI, taxa.plot,
       angle = 90, length = 0.05, code = 3)


# Tolerance Value
boxplot(AvgSens ~ Period, data = sens.mat, ylab = "Mean tolerance value", 
        col = c("plum2", "gold1"))


# Functional Feeding Groups
FFGplot <- t(df.mat)
FFG.barplot <- barplot(FFGplot, beside = TRUE, col = c("plum2", "gold1"), 
                       ylab = "% of community", legend = TRUE, ylim = c(0, 110))
arrows(FFG.barplot[1, ], FFG.95.CI.plot[1, ], FFG.barplot[1, ], FFG.95.CI.plot[2, ], 
       code = 3, angle = 90, length = 0.05)
arrows(FFG.barplot[2, ], FFG.95.CI.plot[3, ], FFG.barplot[2, ], FFG.95.CI.plot[4, ], 
       code = 3, angle = 90, length = 0.05)


# Functional Dendrogam
plot(hc.trichop, main = "Trichoptera functional diversity")


## Functional trait diversity

# Bar dodge to have grouped bars
dodge <- position_dodge(0.90)

## FRic plot
FRic.plot <- 
  ggplot(data = FRic.summary, 
         aes(x = Season, y = mean, fill = Period)) +
  geom_bar(stat = "identity", position = dodge) +
  geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
                width = 0.2, size = 0.5, position = dodge, color = "gray0") + 
  labs(y = "FRic") +
  scale_x_discrete(limits = c("spring", "summer", "fall", "winter"),
                   labels = c("spring" = "Spring", "summer" = "Summer", 
                              "fall" = "Fall", "winter" = "Winter")) +
  scale_fill_manual(values = c("plum2", "gold1")) +
  scale_y_continuous(breaks = c(0, 0.5, 1.0), limits = c(0, 1.1)) +
  theme(legend.position = "none",
        axis.text.y = element_text(size = 12, colour = "gray40"),
        axis.text.x = element_text(size = 12, colour = "white"),
        axis.title.y = element_text(size = 14, colour = "gray0"),
        axis.title.x = element_text(size = 14, colour = "white"),
        panel.background = element_blank(),
        axis.line.x = element_line(colour = "gray0",  size = 0.5),
        axis.line.y = element_line(colour = "gray0",  size = 0.5)) +
  ggtitle("(a)")
FRic.plot

## FEve plot
FEve.plot <- 
  ggplot(data = FEve.summary, 
         aes(x = Season, y = mean, fill = Period)) +
  geom_bar(stat = "identity", position = dodge) +
  geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
                width = 0.2, size = 0.5, position = dodge, color = "gray0") + 
  labs(y = "FEve") +
  scale_x_discrete(limits = c("spring", "summer", "fall", "winter"),
                   labels = c("spring" = "Spring", "summer" = "Summer", 
                              "fall" = "Fall", "winter" = "Winter")) +
  scale_fill_manual(values = c("plum2", "gold1")) +
  scale_y_continuous(breaks = c(0, 0.5, 0.8), limits = c(0, 0.9)) +
  theme(legend.position = "none",
        axis.text.y = element_text(size = 12, colour = "gray40"),
        axis.text.x = element_text(size = 12, colour = "white"),
        axis.title.y = element_text(size = 14, colour = "gray0"),
        axis.title.x = element_text(size = 14, colour = "white"),
        panel.background = element_blank(),
        axis.line.x = element_line(colour = "gray0",  size = 0.5),
        axis.line.y = element_line(colour = "gray0",  size = 0.5)) +
  ggtitle("(b)")
FEve.plot

## FDiv plot
FDiv.plot <- 
  ggplot(data = FDiv.summary, 
         aes(x = Season, y = mean, fill = Period)) +
  geom_bar(stat = "identity", position = dodge) +
  geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
                width = 0.2, size = 0.5, position = dodge, color = "gray0") + 
  labs(y = "FDiv") +
  scale_x_discrete(limits = c("spring", "summer", "fall", "winter"),
                   labels = c("spring" = "Spring", "summer" = "Summer", 
                              "fall" = "Fall", "winter" = "Winter")) +
  scale_fill_manual(values = c("plum2", "gold1")) +
  scale_y_continuous(breaks = c(0, 0.5, 0.8), limits = c(0, 0.9)) +
  theme(axis.text.y   = element_text(size = 12, colour = "gray40"),
        axis.text.x   = element_text(size = 12, colour = "gray40"),
        axis.title.y  = element_text(size = 14, colour = "gray0"),
        axis.title.x  = element_text(size = 14, colour = "gray0"),
        panel.background = element_blank(),
        axis.line.x = element_line(colour = "gray0",  size = 0.5),
        axis.line.y = element_line(colour = "gray0",  size = 0.5)) +
  ggtitle("(c)")
FDiv.plot

## FDis plot
FDis.plot <- 
  ggplot(data = FDis.summary, 
         aes(x = Season, y = mean, fill = Period)) +
  geom_bar(stat = "identity", position = dodge) +
  geom_errorbar(mapping = aes(ymin = LL, ymax = UL), 
                width = 0.2, size = 0.5, position = dodge, color = "gray0") + 
  labs(y = "FDis") +
  scale_x_discrete(limits = c("spring", "summer", "fall", "winter"),
                   labels = c("spring" = "Spring", "summer" = "Summer", 
                              "fall" = "Fall", "winter" = "Winter")) +
  scale_fill_manual(values = c("plum2", "gold1")) +
  scale_y_continuous(breaks = c(0, 2.5, 5), limits = c(0, 5.1)) +
  theme(axis.text.y   = element_text(size = 12, colour = "gray40"),
        axis.text.x   = element_text(size = 12, colour = "gray40"),
        axis.title.y  = element_text(size = 14, colour = "gray0"),
        axis.title.x  = element_text(size = 14, colour = "gray0"),
        panel.background = element_blank(),
        axis.line.x = element_line(colour = "gray0",  size = 0.5),
        axis.line.y = element_line(colour = "gray0",  size = 0.5)) +
  ggtitle("(d)")
FDis.plot

## Arrange all functional trait diversity plots into a panel figure
grid_arrange_shared_legend(FRic.plot, FEve.plot, FDiv.plot, FDis.plot,
                           nrow = 2, ncol = 2)


## End of script-----------------------------------------------------------
